@@ -42,16 +42,13 @@
 
 #include "gnome-canvas-shape.h"
 
-
 #define NUM_STATIC_POINTS 256	/* Number of static points to use to avoid allocating arrays */
 
-
 enum {
 	PROP_0,
 	PROP_POINTS
 };
 
-
 static void gnome_canvas_polygon_class_init (GnomeCanvasPolygonClass *class);
 static void gnome_canvas_polygon_init       (GnomeCanvasPolygon      *poly);
 static void gnome_canvas_polygon_destroy    (GtkObject               *object);
@@ -74,7 +71,7 @@ gnome_canvas_polygon_get_type (void)
 	static GType polygon_type;
 
 	if (!polygon_type) {
-		static const GTypeInfo object_info = {
+		const GTypeInfo object_info = {
 			sizeof (GnomeCanvasPolygonClass),
 			(GBaseInitFunc) NULL,
 			(GBaseFinalizeFunc) NULL,
